# Examples of how to use geo-track-analyzer
This directory collects examples showcasing various capabilities of the `geo_track_analyzer` package.

All examples can be executed standalone via the terminal in a environmant with installed `geo_track_analyzer`. Some examples my require internet collection for
sending requests to REST APIs.

If you got an example you would like to see here, please feel free to open an issue. Otherwise if you got an example you would like to add, feel free to make a PR.